==> chromium_102.0.5005.61.orig.tar.xz: chromium-102.0.5005.61/ash/services/device_sync/fake_remote_device_v2_loader.h <==
// Copyright 2019 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#ifndef ASH_SERVICES_DEVICE_SYNC_FAKE_REMOTE_DEVICE_V2_LOADER_H_
#define ASH_SERVICES_DEVICE_SYNC_FAKE_REMOTE_DEVICE_V2_LOADER_H_

#include <memory>
#include <string>
#include <vector>

#include "ash/components/multidevice/remote_device.h"
#include "ash/services/device_sync/cryptauth_device_registry.h"
#include "ash/services/device_sync/remote_device_v2_loader.h"
#include "ash/services/device_sync/remote_device_v2_loader_impl.h"
#include "third_party/abseil-cpp/absl/types/optional.h"

namespace ash {

namespace device_sync {

class FakeRemoteDeviceV2Loader : public RemoteDeviceV2Loader {
 public:
  FakeRemoteDeviceV2Loader();

  // Disallow copy and assign.
  FakeRemoteDeviceV2Loader(const FakeRemoteDeviceV2Loader&) = delete;
  FakeRemoteDeviceV2Loader& operator=(const FakeRemoteDeviceV2Loader&) = delete;

  ~FakeRemoteDeviceV2Loader() override;

  // Returns the Instance ID to device map that was passed into Load(). Returns
  // null if Load() has not been called.
  const absl::optional<CryptAuthDeviceRegistry::InstanceIdToDeviceMap>&
  id_to_device_map() const {
    return id_to_device_map_;
  }

  // Returns the user email that was passed into Load(). Returns null if Load()
  // has not been called.
  const absl::optional<std::string>& user_email() const { return user_email_; }

  // Returns the user private key that was passed into Load(). Returns null if
  // Load() has not been called.
  const absl::optional<std::string>& user_private_key() const {
    return user_private_key_;
  }

  LoadCallback& callback() { return callback_; }

 private:
  // RemoteDeviceV2Loader:
  void Load(
      const CryptAuthDeviceRegistry::InstanceIdToDeviceMap& id_to_device_map,
      const std::string& user_email,
      const std::string& user_private_key,
      LoadCallback callback) override;

  absl::optional<CryptAuthDeviceRegistry::InstanceIdToDeviceMap>
      id_to_device_map_;
  absl::optional<std::string> user_email_;
  absl::optional<std::string> user_private_key_;
  LoadCallback callback_;
};

class FakeRemoteDeviceV2LoaderFactory
    : public RemoteDeviceV2LoaderImpl::Factory {
 public:
  FakeRemoteDeviceV2LoaderFactory();

  // Disallow copy and assign.
  FakeRemoteDeviceV2LoaderFactory(const FakeRemoteDeviceV2LoaderFactory&) =
      delete;
  FakeRemoteDeviceV2LoaderFactory& operator=(const FakeRemoteDeviceV2Loader&) =
      delete;

  ~FakeRemoteDeviceV2LoaderFactory() override;

  // Returns a vector of all FakeRemoteDeviceV2Loader instances created by
  // CreateInstance().
  const std::vector<FakeRemoteDeviceV2Loader*>& instances() const {
    return instances_;
  }

 private:
  // RemoteDeviceV2LoaderImpl::Factory:
  std::unique_ptr<RemoteDeviceV2Loader> CreateInstance() override;

  std::vector<FakeRemoteDeviceV2Loader*> instances_;
};

}  // namespace device_sync

}  // namespace ash

#endif  // ASH_SERVICES_DEVICE_SYNC_FAKE_REMOTE_DEVICE_V2_LOADER_H_

==> chromium_108.0.5359.124.orig.tar.xz: chromium-108.0.5359.124/ash/services/device_sync/fake_remote_device_v2_loader.h <==
// Copyright 2019 The Chromium Authors
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#ifndef ASH_SERVICES_DEVICE_SYNC_FAKE_REMOTE_DEVICE_V2_LOADER_H_
#define ASH_SERVICES_DEVICE_SYNC_FAKE_REMOTE_DEVICE_V2_LOADER_H_

#include <memory>
#include <string>
#include <vector>

#include "ash/services/device_sync/cryptauth_device_registry.h"
#include "ash/services/device_sync/remote_device_v2_loader.h"
#include "ash/services/device_sync/remote_device_v2_loader_impl.h"
#include "chromeos/ash/components/multidevice/remote_device.h"
#include "third_party/abseil-cpp/absl/types/optional.h"

namespace ash {

namespace device_sync {

class FakeRemoteDeviceV2Loader : public RemoteDeviceV2Loader {
 public:
  FakeRemoteDeviceV2Loader();

  // Disallow copy and assign.
  FakeRemoteDeviceV2Loader(const FakeRemoteDeviceV2Loader&) = delete;
  FakeRemoteDeviceV2Loader& operator=(const FakeRemoteDeviceV2Loader&) = delete;

  ~FakeRemoteDeviceV2Loader() override;

  // Returns the Instance ID to device map that was passed into Load(). Returns
  // null if Load() has not been called.
  const absl::optional<CryptAuthDeviceRegistry::InstanceIdToDeviceMap>&
  id_to_device_map() const {
    return id_to_device_map_;
  }

  // Returns the user email that was passed into Load(). Returns null if Load()
  // has not been called.
  const absl::optional<std::string>& user_email() const { return user_email_; }

  // Returns the user private key that was passed into Load(). Returns null if
  // Load() has not been called.
  const absl::optional<std::string>& user_private_key() const {
    return user_private_key_;
  }

  LoadCallback& callback() { return callback_; }

 private:
  // RemoteDeviceV2Loader:
  void Load(
      const CryptAuthDeviceRegistry::InstanceIdToDeviceMap& id_to_device_map,
      const std::string& user_email,
      const std::string& user_private_key,
      LoadCallback callback) override;

  absl::optional<CryptAuthDeviceRegistry::InstanceIdToDeviceMap>
      id_to_device_map_;
  absl::optional<std::string> user_email_;
  absl::optional<std::string> user_private_key_;
  LoadCallback callback_;
};

class FakeRemoteDeviceV2LoaderFactory
    : public RemoteDeviceV2LoaderImpl::Factory {
 public:
  FakeRemoteDeviceV2LoaderFactory();

  // Disallow copy and assign.
  FakeRemoteDeviceV2LoaderFactory(const FakeRemoteDeviceV2LoaderFactory&) =
      delete;
  FakeRemoteDeviceV2LoaderFactory& operator=(const FakeRemoteDeviceV2Loader&) =
      delete;

  ~FakeRemoteDeviceV2LoaderFactory() override;

  // Returns a vector of all FakeRemoteDeviceV2Loader instances created by
  // CreateInstance().
  const std::vector<FakeRemoteDeviceV2Loader*>& instances() const {
    return instances_;
  }

 private:
  // RemoteDeviceV2LoaderImpl::Factory:
  std::unique_ptr<RemoteDeviceV2Loader> CreateInstance() override;

  std::vector<FakeRemoteDeviceV2Loader*> instances_;
};

}  // namespace device_sync

}  // namespace ash

#endif  // ASH_SERVICES_DEVICE_SYNC_FAKE_REMOTE_DEVICE_V2_LOADER_H_
